/* file model.c
 *
 *
 List of know printers and flags
 * device and printer choice
 *
 */

#include "model.h"

configData_t defaultConfigData[] = {
   { "Stylus C20SX",          4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
   { "Stylus C20UX",          4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
   { "Stylus C40SX",          4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
   { "Stylus C40UX",          4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
   { "Stylus C42",            4, PROT_D4,          True,  True,  True,  True,  PROT_D4,          PROT_D4,          True,  -3, 15,  0,  0, False, "/C42.align" },
   { "Stylus C42SX",          4, PROT_D4,          True,  True,  True,  True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
   { "Stylus C42UX",          4, PROT_D4,          True,  True,  True,  True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
   { "Stylus C50",            4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus C60",            4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus C62",            4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus C70",            4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus C80",            4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus C82",            4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
   { "Stylus C84",            4, PROT_D4,          True,  False, False, True,  PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
   { "Stylus C86",            7, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
   { "Stylus Color",          4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color 300",      4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color 400",      4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color 440",      4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1, 15,  0,  0, False, NULL },
   { "Stylus Color 460",      4, PROT_NEW,         True,  False, False, False, PROT_NEW,         PROT_NEW,         True,   1, 15,  0,  0, False, NULL },
   { "Stylus Color 480",      4, PROT_D4,          True,  True,  True,  True,  PROT_NEW,         PROT_NEW,         True,   3, 15,  2,  9, False, NULL },
   { "Stylus Color 500",      4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color 580",      4, PROT_D4,          True,  True,  True,  True,  PROT_D4,          PROT_D4,          True,   3, 15,  2,  9, False, NULL },
   { "Stylus Color 600",      4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color 640",      4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1, 15,  0,  0, False, NULL },
   { "Stylus Color 660",      4, PROT_NEW,         True,  False, False, False, PROT_NEW,         PROT_NEW,         True,   1, 15,  0,  0, False, NULL },
   { "Stylus Color 670",      4, PROT_NEW,         True,  False, False, False, PROT_NEW,         PROT_NEW,         True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 680",      4, PROT_NEW,         True,  False, False, False, PROT_NEW,         PROT_NEW,         True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 685",      4, PROT_NEW,         True,  False, False, False, PROT_NEW,         PROT_NEW,         True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 740",      4, PROT_NEW,         True,  False, False, False, PROT_NEW,         PROT_NEW,         True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 760",      4, PROT_NEW,         True,  False, False, False, PROT_NEW,         PROT_NEW,         True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 777",      4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 800",      4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color 850",      4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color 860",      4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 880",      4, PROT_NEW,         True,  False, False, False, PROT_NEW,         PROT_NEW,         True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 900",      4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 980",      4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Color 1160",     4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   2, 15,  0,  0, False, NULL },
   { "Stylus Color 1500",     4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color 1520",     4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color 3000",     4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color Pro",      4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Color Pro XL",   4, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus CX3200",         4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          False,  0,  0,  0,  0, False, NULL },
   { "Stylus Photo",          6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Photo 200R",     7, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
   { "Stylus Photo 300R",     7, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
   { "Stylus Photo 700",      6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1, 15,  0,  0, False, NULL },
   { "Stylus Photo 720",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 750",      6, PROT_NEW,         True,  False, False, False, PROT_NEW,         PROT_NEW,         True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 780",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 785",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 790",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 810",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 820",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, "Pattern820" },
   { "Stylus Photo 830",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, "Pattern820" },
   { "Stylus Photo 870",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 875",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 875DC",    6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 890",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, True,  NULL },
   { "Stylus Photo 895",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, True,  NULL },
   { "Stylus Photo 895EX",    6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, True,  NULL },
   { "Stylus Photo 900",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 900R",     7, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
   { "Stylus Photo 915",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 925",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 950",      7, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 1200",     6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 1270",     6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 1280",     6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 1290",     6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, True,  NULL },
   { "Stylus Photo 1290S",    6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Photo 2000P",    6, PROT_D4,          True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   2, 15,  0,  0, False, NULL },
   { "Stylus Photo 2100",     7, PROT_D4,          True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   2, 15,  0,  0, False, NULL },
   { "Stylus Photo EX",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Photo R800",     8, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
   { "Stylus Photo R2400",    8, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
   { "Stylus Pro 5000",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Pro 5500",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Pro 7000",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Pro 7500",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Pro 7600",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Pro 9000",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Pro 9500",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Pro 9600",       6, PROT_OLD,         True,  False, False, False, PROT_OLD,         PROT_OLD,         True,   1,  7,  0,  0, False, NULL },
   { "Stylus Pro 10000",      6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Pro 10000CF",    6, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   3, 15,  0,  0, False, NULL },
   { "Stylus Scan 2000",      4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          False,  3, 15,  0,  0, False, NULL },
   { "Stylus Scan 2500",      4, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          False,  3, 15,  0,  0, False, NULL },
   { "???",                   8, PROT_D4,          True,  False, False, False, PROT_D4,          PROT_D4,          True,   0,  0,  0,  0, False, NULL },
};

configData_t defaultConfigData[];
int          defaultConfigDataSize = sizeof(defaultConfigData) / sizeof(configData_t);

